@@ -4,19 +4,9 @@ package Bio::ToolBox::db_helper::wiggle;
 require Exporter;
 use strict;
 use Carp;
+use Bio::ToolBox::db_helper::constants;
 use Bio::Graphics::Wiggle;
-use constant {
-	CHR  => 0,  # chromosome
-	STRT => 1,  # start
-	STOP => 2,  # stop
-	STR  => 3,  # strand
-	STND => 4,  # strandedness
-	METH => 5,  # method
-	RETT => 6,  # return type
-	DB   => 7,  # database object
-	DATA => 8,  # first dataset, additional may be present
-};
-our $VERSION = '1.50';
+our $VERSION = '1.51';
 
 
 # Exported names
